==> u++-4.7.tar.gz: u++-4.7/src/translator/key.cc <==
//                              -*- Mode: C++ -*- 
// 
// uC++ Version 4.7, Copyright (C) Peter A. Buhr and Richard A. Stroobosscher 1994
// 
// key.c -- 
// 
// Author           : Richard A. Stroobosscher
// Created On       : Tue Apr 28 15:06:35 1992
// Last Modified By : Peter A. Buhr
// Last Modified On : Mon Nov  9 17:53:59 1998
// Update Count     : 44
//

#include <stdlib.h>
#include <stdio.h>

#include "key.h"
#include "token.h"
#include "include.h"

keyword_t key[] = {
    { "asm", ASM },
    { "__asm", ASM },					// gcc specific
    { "__asm__", ASM },					// gcc specific
    { "__attribute__", ATTRIBUTE },			// gcc specific
    { "auto", AUTO },
    { "bool", BOOL },
    { "break", BREAK },
    { "case", CASE },
    { "catch", CATCH },
    { "char", CHAR },
    { "class", CLASS },
    { "const", CONST },
    { "__const", CONST },				// gcc specific
    { "__const__", CONST },				// gcc specific
    { "const_cast", CONST_CAST },
    { "continue", CONTINUE },
    { "default", DEFAULT },
    { "delete", DELETE },
    { "do", DO },
    { "double", DOUBLE },
    { "dynamic_cast", DYNAMIC_CAST },
    { "else", ELSE },
    { "enum", ENUM },
    { "explicit", EXPLICIT },
    { "export", EXPORT },
    { "__extension__", EXTENSION },			// gcc specific
    { "extern", EXTERN },
    { "false", FALSE_C },
    { "float", FLOAT },
    { "for", FOR },
    { "friend", FRIEND },
    { "goto", GOTO },
    { "if", IF },
    { "inline", INLINE },
    { "__inline", INLINE },				// gcc specific
    { "__inline__", INLINE },				// gcc specific
    { "int", INT },
    { "long", LONG },
    { "mutable", MUTABLE },
    { "namespace", NAMESPACE },
    { "new", NEW },
    { "operator", OPERATOR },
    { "private", PRIVATE },
    { "protected", PROTECTED },
    { "public", PUBLIC },
    { "register", REGISTER },
    { "reinterpret_cast", REINTERPRET_CAST },
    { "return", RETURN },
    { "short", SHORT },
    { "signed", SIGNED },
    { "__signed", SIGNED },				// gcc specific
    { "__signed__", SIGNED },				// gcc specific
    { "sizeof", SIZEOF },
    { "static", STATIC },
    { "static_cast", STATIC_CAST },
    { "struct", STRUCT },
    { "switch", SWITCH },
    { "template", TEMPLATE },
    { "this", THIS },
    { "throw", THROW },
    { "true", TRUE_C },
    { "try", TRY },
    { "typedef", TYPEDEF },
    { "typeof", TYPEOF },				// gcc specific
    { "__typeof", TYPEOF },				// gcc specific
    { "__typeof__", TYPEOF },				// gcc specific
    { "typeid", TYPEID },
    { "typename", TYPENAME },
    { "union", UNION },
    { "unsigned", UNSIGNED },
    { "using", USING },
    { "virtual", VIRTUAL },
    { "void", VOID },
    { "volatile", VOLATILE },
    { "__volatile", VOLATILE },				// gcc specific
    { "__volatile__", VOLATILE },			// gcc specific
    { "wchar_t", WCHAR_T },
    { "__wchar_t", WCHAR_T },				// gcc specific
    { "while", WHILE },
    
    { "uAccept", ACCEPT },
    { "uAt", AT },
    { "uCoroutine", COROUTINE },
    { "uDisable", DISABLE },
    { "uDualEvent", DUALEVENT },
    { "uElse", UELSE },
    { "uEnable", ENABLE },
    { "uMutex", MUTEX },
    { "uNoMutex", NOMUTEX },
    { "uOr", OR },
    { "uPeriodicTask", PTASK },
    { "uRaise", RAISE },
    { "uRaiseEvent", RAISEEVENT },
    { "uRealTimeTask", RTASK },
    { "uResume", RESUME },
    { "uSignal", SIGNAL },
    { "uSignalBlock", SIGNALBLOCK },
    { "uSporadicTask", STASK },
    { "uSuspend", SUSPEND },
    { "uTask", TASK },
    { "uTimeout", TIMEOUT },
    { "uWait", WAIT },
    { "uWhen", WHEN },
    { "uWith", WITH },
    { "uThrow", UTHROW },
    { "uThrowEvent", THROWEVENT },
    
    { NULL, 0 }
};

// Local Variables: //
// compile-command: "dmake" //
// End: //

==> u++_5.0.1.orig.tar.gz: u++-5.0.1/src/translator/key.cc <==
//                              -*- Mode: C++ -*- 
// 
// uC++ Version 5.0.1, Copyright (C) Peter A. Buhr and Richard A. Stroobosscher 1994
// 
// key.c -- 
// 
// Author           : Richard A. Stroobosscher
// Created On       : Tue Apr 28 15:06:35 1992
// Last Modified By : Peter A. Buhr
// Last Modified On : Sun Aug  8 07:22:55 2004
// Update Count     : 60
//
// This  library is free  software; you  can redistribute  it and/or  modify it
// under the terms of the GNU Lesser General Public License as published by the
// Free Software  Foundation; either  version 2.1 of  the License, or  (at your
// option) any later version.
// 
// This library is distributed in the  hope that it will be useful, but WITHOUT
// ANY  WARRANTY;  without even  the  implied  warranty  of MERCHANTABILITY  or
// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
// for more details.
// 
// You should  have received a  copy of the  GNU Lesser General  Public License
// along  with this library.
//

#include "key.h"

#include <cstddef>					// NULL

keyword_t key[] = {
    { "asm", ASM },
    { "__asm", ASM },					// gcc specific
    { "__asm__", ASM },					// gcc specific
    { "__attribute__", ATTRIBUTE },			// gcc specific
    { "auto", AUTO },
    { "bool", BOOL },
    { "break", BREAK },
    { "case", CASE },
    { "catch", CATCH },
    { "char", CHAR },
    { "class", CLASS },
    { "__complex__", COMPLEX },				// gcc specific
    { "const", CONST },
    { "__const", CONST },				// gcc specific
    { "__const__", CONST },				// gcc specific
    { "const_cast", CONST_CAST },
    { "continue", CONTINUE },
    { "default", DEFAULT },
    { "delete", DELETE },
    { "do", DO },
    { "double", DOUBLE },
    { "dynamic_cast", DYNAMIC_CAST },
    { "else", ELSE },
    { "enum", ENUM },
    { "explicit", EXPLICIT },
    { "export", EXPORT },
    { "__extension__", EXTENSION },			// gcc specific
    { "extern", EXTERN },
    { "false", FALSE_C },
    { "float", FLOAT },
    { "for", FOR },
    { "friend", FRIEND },
    { "goto", GOTO },
    { "if", IF },
    { "inline", INLINE },
    { "__inline", INLINE },				// gcc specific
    { "__inline__", INLINE },				// gcc specific
    { "int", INT },
    { "long", LONG },
    { "mutable", MUTABLE },
    { "namespace", NAMESPACE },
    { "new", NEW },
    { "operator", OPERATOR },
    { "private", PRIVATE },
    { "protected", PROTECTED },
    { "public", PUBLIC },
    { "register", REGISTER },
    { "reinterpret_cast", REINTERPRET_CAST },
    { "return", RETURN },
    { "short", SHORT },
    { "signed", SIGNED },
    { "__signed", SIGNED },				// gcc specific
    { "__signed__", SIGNED },				// gcc specific
    { "sizeof", SIZEOF },
    { "static", STATIC },
    { "static_cast", STATIC_CAST },
    { "struct", STRUCT },
    { "switch", SWITCH },
    { "template", TEMPLATE },
    { "this", THIS },
    { "throw", THROW },
    { "true", TRUE_C },
    { "try", TRY },
    { "typedef", TYPEDEF },
    { "typeof", TYPEOF },				// gcc specific
    { "__typeof", TYPEOF },				// gcc specific
    { "__typeof__", TYPEOF },				// gcc specific
    { "typeid", TYPEID },
    { "typename", TYPENAME },
    { "union", UNION },
    { "unsigned", UNSIGNED },
    { "using", USING },
    { "virtual", VIRTUAL },
    { "void", VOID },
    { "volatile", VOLATILE },
    { "__volatile", VOLATILE },				// gcc specific
    { "__volatile__", VOLATILE },			// gcc specific
    { "wchar_t", WCHAR_T },
    { "__wchar_t", WCHAR_T },				// gcc specific
    { "while", WHILE },
    
    { "uAccept", ACCEPT },				// uC++ specific
    { "uAcceptReturn", ACCEPTRETURN },
    { "uAcceptWait", ACCEPTWAIT },
    { "uAt", AT },
    { "uCoroutine", COROUTINE },
    { "uDisable", DISABLE },
    { "uDualEvent", DUALEVENT },
    { "uElse", UELSE },
    { "uEnable", ENABLE },
    { "uMutex", MUTEX },
    { "uNoMutex", NOMUTEX },
    { "uOr", OR },
    { "uPeriodicTask", PTASK },
    { "uRaise", RAISE },
    { "uRaiseEvent", RAISEEVENT },
    { "uRealTimeTask", RTASK },
    { "uResume", RESUME },
    { "uSignal", SIGNAL },
    { "uSignalBlock", SIGNALBLOCK },
    { "uSporadicTask", STASK },
    { "uSuspend", SUSPEND },
    { "uTask", TASK },
    { "uTimeout", TIMEOUT },
    { "uWait", WAIT },
    { "uWhen", WHEN },
    { "uWith", WITH },
    { "uThrow", UTHROW },
    { "uThrowEvent", THROWEVENT },
    
    { NULL, 0 }
};

// Local Variables: //
// compile-command: "gmake install" //
// End: //
